@@ -1,6 +1,8 @@
 import asyncio
 import contextlib
 import io
+import os
+import pathlib
 import ssl
 import typing
 import warnings
@@ -104,10 +106,9 @@ class BaseBot:
 
         self.parse_mode = parse_mode
 
-    def get_new_session(self) -> aiohttp.ClientSession:
+    async def get_new_session(self) -> aiohttp.ClientSession:
         return aiohttp.ClientSession(
-            connector=self._connector_class(**self._connector_init, loop=self._main_loop),
-            loop=self._main_loop,
+            connector=self._connector_class(**self._connector_init),
             json_serialize=json.dumps
         )
 
@@ -115,10 +116,25 @@ class BaseBot:
     def loop(self) -> Optional[asyncio.AbstractEventLoop]:
         return self._main_loop
 
-    @property
-    def session(self) -> Optional[aiohttp.ClientSession]:
+    async def get_session(self) -> Optional[aiohttp.ClientSession]:
         if self._session is None or self._session.closed:
-            self._session = self.get_new_session()
+            self._session = await self.get_new_session()
+
+        if not self._session._loop.is_running():  # NOQA
+            # Hate `aiohttp` devs because it juggles event-loops and breaks already opened session
+            # So... when we detect a broken session need to fix it by re-creating it
+            # @asvetlov, if you read this, please no more juggle event-loop inside aiohttp, it breaks the brain.
+            await self._session.close()
+            self._session = await self.get_new_session()
+
+        return self._session
+
+    @property
+    @deprecated(
+        reason="Client session should be created inside async function, use `await bot.get_session()` instead",
+        stacklevel=3,
+    )
+    def session(self) -> Optional[aiohttp.ClientSession]:
         return self._session
 
     @staticmethod
@@ -184,7 +200,8 @@ class BaseBot:
         """
         Close all client sessions
         """
-        await self.session.close()
+        if self._session:
+            await self._session.close()
 
     async def request(self, method: base.String,
                       data: Optional[Dict] = None,
@@ -204,35 +221,57 @@ class BaseBot:
         :rtype: Union[List, Dict]
         :raise: :obj:`aiogram.exceptions.TelegramApiError`
         """
-        return await api.make_request(self.session, self.server, self.__token, method, data, files,
+
+        return await api.make_request(await self.get_session(), self.server, self.__token, method, data, files,
                                       proxy=self.proxy, proxy_auth=self.proxy_auth, timeout=self.timeout, **kwargs)
 
-    async def download_file(self, file_path: base.String,
-                            destination: Optional[base.InputFile] = None,
-                            timeout: Optional[base.Integer] = sentinel,
-                            chunk_size: Optional[base.Integer] = 65536,
-                            seek: Optional[base.Boolean] = True) -> Union[io.BytesIO, io.FileIO]:
+    async def download_file(
+            self,
+            file_path: base.String,
+            destination: Optional[Union[base.InputFile, pathlib.Path]] = None,
+            timeout: Optional[base.Integer] = sentinel,
+            chunk_size: Optional[base.Integer] = 65536,
+            seek: Optional[base.Boolean] = True,
+            destination_dir: Optional[Union[str, pathlib.Path]] = None,
+            make_dirs: Optional[base.Boolean] = True,
+    ) -> Union[io.BytesIO, io.FileIO]:
         """
-        Download file by file_path to destination
+        Download file by file_path to destination file or directory
 
         if You want to automatically create destination (:class:`io.BytesIO`) use default
         value of destination and handle result of this method.
 
+        At most one of these parameters can be used: :param destination:, :param destination_dir:
+
         :param file_path: file path on telegram server (You can get it from :obj:`aiogram.types.File`)
         :type file_path: :obj:`str`
         :param destination: filename or instance of :class:`io.IOBase`. For e. g. :class:`io.BytesIO`
         :param timeout: Integer
         :param chunk_size: Integer
         :param seek: Boolean - go to start of file when downloading is finished.
+        :param destination_dir: directory for saving files
+        :param make_dirs: Make dirs if not exist
         :return: destination
         """
-        if destination is None:
+        if destination and destination_dir:
+            raise ValueError(
+                "Use only one of the parameters:destination or destination_dir."
+            )
+
+        if destination is None and destination_dir is None:
             destination = io.BytesIO()
 
+        elif destination_dir:
+            destination = os.path.join(destination_dir, file_path)
+
+        if make_dirs and not isinstance(destination, io.IOBase) and os.path.dirname(destination):
+            os.makedirs(os.path.dirname(destination), exist_ok=True)
+
         url = self.get_file_url(file_path)
 
         dest = destination if isinstance(destination, io.IOBase) else open(destination, 'wb')
-        async with self.session.get(url, timeout=timeout, proxy=self.proxy, proxy_auth=self.proxy_auth) as response:
+        session = await self.get_session()
+        async with session.get(url, timeout=timeout, proxy=self.proxy, proxy_auth=self.proxy_auth) as response:
             while True:
                 chunk = await response.content.read(chunk_size)
                 if not chunk:
