@@ -1,6 +1,5 @@
-import time
-
 import logging
+import time
 
 from aiogram import types
 from aiogram.dispatcher.middlewares import BaseMiddleware
@@ -89,13 +88,15 @@ class LoggingMiddleware(BaseMiddleware):
 
     async def on_pre_process_callback_query(self, callback_query: types.CallbackQuery, data: dict):
         if callback_query.message:
+            message = callback_query.message
             text = (f"Received callback query [ID:{callback_query.id}] "
                     f"from user [ID:{callback_query.from_user.id}] "
-                    f"for message [ID:{callback_query.message.message_id}] "
-                    f"in chat [{callback_query.message.chat.type}:{callback_query.message.chat.id}]")
+                    f"for message [ID:{message.message_id}] "
+                    f"in chat [{message.chat.type}:{message.chat.id}]"
+                    f"with data: {callback_query.data}")
 
-            if callback_query.message.from_user:
-                text += f" originally posted by user [ID:{callback_query.message.from_user.id}]"
+            if message.from_user:
+                text = f"{text} originally posted by user [ID:{message.from_user.id}]"
 
             self.logger.info(text)
 
@@ -106,14 +107,16 @@ class LoggingMiddleware(BaseMiddleware):
 
     async def on_post_process_callback_query(self, callback_query, results, data: dict):
         if callback_query.message:
+            message = callback_query.message
             text = (f"{HANDLED_STR[bool(len(results))]} "
                     f"callback query [ID:{callback_query.id}] "
                     f"from user [ID:{callback_query.from_user.id}] "
-                    f"for message [ID:{callback_query.message.message_id}] "
-                    f"in chat [{callback_query.message.chat.type}:{callback_query.message.chat.id}]")
+                    f"for message [ID:{message.message_id}] "
+                    f"in chat [{message.chat.type}:{message.chat.id}] "
+                    f"with data: {callback_query.data}")
 
-            if callback_query.message.from_user:
-                text += f" originally posted by user [ID:{callback_query.message.from_user.id}]"
+            if message.from_user:
+                text = f"{text} originally posted by user [ID:{message.from_user.id}]"
 
             self.logger.info(text)
 
@@ -180,6 +183,16 @@ class LoggingMiddleware(BaseMiddleware):
         self.logger.debug(f"{HANDLED_STR[bool(len(results))]} chat_member "
                           f"for user [ID:{chat_member_update.from_user.id}]")
 
+    async def on_pre_chat_join_request(self, chat_join_request, data):
+        self.logger.info(f"Received chat join request "
+                         f"for user [ID:{chat_join_request.from_user.id}] "
+                         f"in chat [ID:{chat_join_request.chat.id}]")
+
+    async def on_post_chat_join_request(self, chat_join_request, results, data):
+        self.logger.debug(f"{HANDLED_STR[bool(len(results))]} chat join request "
+                          f"for user [ID:{chat_join_request.from_user.id}] "
+                          f"in chat [ID:{chat_join_request.chat.id}]")
+
 
 class LoggingFilter(logging.Filter):
     """
